==> apache-tinkerpop-3.3.8-src.zip: tinkerpop-3.3.8/gremlin-core/src/test/java/org/apache/tinkerpop/gremlin/process/traversal/OperatorExceptionTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.tinkerpop.gremlin.process.traversal;

import org.junit.Test;

/**
 * @author Stephen Mallette (http://stephen.genoprime.com)
 */
public class OperatorExceptionTest {

    @Test(expected = ClassCastException.class)
    public void shouldThrowIfValueToDivIsNotNumeric() {
        Operator.div.apply("1", "1");
    }

    @Test(expected = ClassCastException.class)
    public void shouldThrowIfValueToMaxIsNotNumeric() {
        Operator.max.apply("1", "1");
    }

    @Test(expected = ClassCastException.class)
    public void shouldThrowIfValueToMinIsNotNumeric() {
        Operator.min.apply("1", "1");
    }

    @Test(expected = ClassCastException.class)
    public void shouldThrowIfValueToMinusIsNotNumeric() {
        Operator.minus.apply("1", "1");
    }

    @Test(expected = ClassCastException.class)
    public void shouldThrowIfValueToMultIsNotNumeric() {
        Operator.mult.apply("1", "1");
    }

    @Test(expected = ClassCastException.class)
    public void shouldThrowIfValueToSumIsNotNumeric() {
        Operator.sum.apply("1", "1");
    }
}

==> apache-tinkerpop-3.8.0-src.zip: tinkerpop-3.8.0/gremlin-core/src/test/java/org/apache/tinkerpop/gremlin/process/traversal/OperatorExceptionTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.tinkerpop.gremlin.process.traversal;

import java.util.Arrays;
import org.junit.Test;

/**
 * @author Stephen Mallette (http://stephen.genoprime.com)
 */
public class OperatorExceptionTest {

    @Test(expected = ClassCastException.class)
    public void shouldThrowIfValueToDivIsNotNumeric() {
        Operator.div.apply("1", "1");
    }

    @Test(expected = ClassCastException.class)
    public void shouldThrowIfValueToMinusIsNotNumeric() {
        Operator.minus.apply("1", "1");
    }

    @Test(expected = ClassCastException.class)
    public void shouldThrowIfValueToMultIsNotNumeric() {
        Operator.mult.apply("1", "1");
    }

    @Test(expected = ClassCastException.class)
    public void shouldThrowIfValueToSumIsNotNumeric() {
        Operator.sum.apply("1", "1");
    }

    @Test(expected = IllegalArgumentException.class)
    public void shouldThrowForAddAllIfBothArgsNotCollection() {
        Operator.addAll.apply(Arrays.asList(1,2,3), "not a collection");
    }
}
